@@ -18,7 +18,9 @@ class RedisQueueMixin:
         self.current_redis_msg = None
 
     async def on_pending(self):
-        self.redis_url = self.get_param('/oic/con', 'redis_url', 'redis://localhost')
+        self.redis_url = self.get_param('/oic/con', 'redis_url')
+        if not self.redis_url:
+            return
         self.redis_queues = [self.get_device_id()]
         for href in self.data:
             if 'bubot.redis.queue' in self.data[href].get('rt', []):
@@ -93,8 +95,6 @@ class RedisQueueMixin:
         raw_data = bson.encode(request.to_dict())
         self.log.info(f'send request {request.ri} in redis queue {href}')
         await self.redis.rpush(href, raw_data)
-        self.log.debug(f'wait request {request.ri} in redis queue {src_redis}')
-
         waiter = Waiter(request)
         self._redis_waited_answer[waiter.key] = waiter
         return waiter
